decode_const

Function decode_const 

pub const fn decode_const<const N: usize>(hex: &[u8]) -> [u8; N]
A const fn to decode a hex string to a fixed-length array at compile time. Panics if the input was not a valid hex string.

To decode to a fixed-length array without panicking on invalid inputs, use the FromHex trait instead, e.g. <[u8; 32]>::from_hex(&s).